@@ -206,24 +206,7 @@ static inline void *fc_solve_hash_insert(
          (FCS_STACK_STORAGE == FCS_STACK_STORAGE_INTERNAL_HASH)) ||            \
      (FCS_STATE_STORAGE == FCS_STATE_STORAGE_INTERNAL_HASH))
 
-typedef unsigned long ul;
-typedef unsigned char ub1;
-
-static inline ul perl_hash_function(register const ub1 *s_ptr, /* the key */
-    register const ul len /* the length of the key */
-)
-{
-    register ul hash_value_int = 0;
-    register const ub1 *const s_end = s_ptr + len;
-
-    while (s_ptr < s_end)
-    {
-        hash_value_int += (hash_value_int << 5) + *(s_ptr++);
-    }
-    hash_value_int += (hash_value_int >> 5);
-
-    return hash_value_int;
-}
+#include "wrap_xxhash.h"
 #endif
 
 #ifdef INDIRECT_STACK_STATES
@@ -300,10 +283,10 @@ static inline void fc_solve_cache_stacks(
         }
 #endif
 
-        cached_stack = fc_solve_hash_insert(&(instance->stacks_hash), column,
-            perl_hash_function((ub1 *)*(current_stack), col_len)
+        cached_stack = fc_solve_hash_insert(
+            &(instance->stacks_hash), column, DO_XXH(*(current_stack), col_len)
 #ifdef FCS_ENABLE_SECONDARY_HASH_VALUE
-                ,
+                                                  ,
             hash_value_int
 #endif
         );
@@ -443,6 +426,17 @@ static inline fcs_bool_t handle_existing_void(
     else
     {
         ON_STATE_NEW();
+#ifdef DEBUG
+        if (getenv("FCS_DEBUG2"))
+        {
+            printf("%s", "\n\nAdded state: ");
+            for (size_t i = 0; i < sizeof(new_state->key[0]); ++i)
+            {
+                printf("\\x%02x", (int)((unsigned char *)(new_state->key))[i]);
+            }
+            printf("\n\n");
+        }
+#endif
         return TRUE;
     }
 }
@@ -509,9 +503,8 @@ fcs_bool_t fc_solve_check_and_add_state(
 #else
 #define B
 #endif
-    return HANDLE_existing_void(fc_solve_hash_insert(&(instance->hash), A,
-        perl_hash_function((ub1 *)(new_state_key), sizeof(*(new_state_key)))
-            B));
+    return HANDLE_existing_void(fc_solve_hash_insert(
+        &(instance->hash), A, DO_XXH(new_state_key, sizeof(*new_state_key)) B));
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GOOGLE_DENSE_HASH)
     void *existing_void;
     if (!fc_solve_states_google_hash_insert(instance->hash,
