@@ -18,14 +18,6 @@
 extern "C" {
 #endif
 
-#include <string.h>
-#include <limits.h>
-#include <stdio.h>
-#include <unistd.h>
-
-#include "config.h"
-#include "state.h"
-
 #include "offloading_queue.h"
 
 typedef struct
@@ -58,7 +50,7 @@ static inline void fcs_depth_multi_queue__new_queue(
         ,
         queue->meta_alloc
 #endif
-            );
+    );
 }
 
 static inline void fcs_depth_multi_queue__insert(
@@ -105,7 +97,7 @@ static inline void fcs_depth_multi_queue__init(
 static inline void fcs_depth_multi_queue__destroy(
     fcs_depth_multi_queue_t *const queue)
 {
-    int limit = queue->max_depth - queue->min_depth;
+    const int limit = queue->max_depth - queue->min_depth;
     if (queue->queues_by_depth == NULL)
     {
         return;
