@@ -9,7 +9,6 @@
  */
 // freecell.c - a module that contains moves of the Freecell-games family.
 
-#include <assert.h>
 #include "scans.h"
 #include "freecell.h"
 #include "meta_move_funcs_helpers.h"
@@ -257,7 +256,6 @@ static inline empty_two_cols_ret_t empty_two_cols_from_new_state(
         /*  Find a vacant stack */
         put_cards_in_col_idx = find_empty_stack(
             *kv_ptr_new_state, put_cards_in_col_idx, LOCAL_STACKS_NUM);
-        assert(put_cards_in_col_idx < LOCAL_STACKS_NUM);
 
         fcs_copy_stack(*new_key, *(kv_ptr_new_state->val), put_cards_in_col_idx,
             indirect_stacks_buffer);
@@ -604,12 +602,12 @@ static inline void col_seqs_iter__calc_end(col_seqs_iter_t *const iter)
 #ifndef FCS_FREECELL_ONLY
     const_SLOT(sequences_are_built_by, iter);
 #endif
+    const_SLOT(col, iter);
     for ((*iter).seq_end = (*iter).c; (*iter).seq_end < (*iter).col_len_minus_1;
          ++((*iter).seq_end))
     {
-        if (!fcs_is_parent_card(
-                fcs_col_get_card((*iter).col, (*iter).seq_end + 1),
-                fcs_col_get_card((*iter).col, (*iter).seq_end)))
+        if (!fcs_is_parent_card(fcs_col_get_card(col, (*iter).seq_end + 1),
+                fcs_col_get_card(col, (*iter).seq_end)))
         {
             break;
         }
