@@ -153,7 +153,7 @@ extern guint fc_solve_hash_function(gconstpointer key);
     fc_solve_hard_thread_t *hard_thread = instance->hard_threads;              \
     fc_solve_hard_thread_t *const end_hard_thread =                            \
         hard_thread + instance->num_hard_threads;                              \
-    for (; hard_thread < end_hard_thread; hard_thread++)
+    for (; hard_thread < end_hard_thread; ++hard_thread)
 #endif
 
 /* ST_LOOP == soft threads' loop - macros to abstract it. */
@@ -163,7 +163,7 @@ extern guint fc_solve_hash_function(gconstpointer key);
     fc_solve_soft_thread_t *soft_thread = ht_soft_threads;                     \
     fc_solve_soft_thread_t *const end_soft_thread =                            \
         ht_soft_threads + HT_FIELD(hard_thread, num_soft_threads);             \
-    for (; soft_thread < end_soft_thread; soft_thread++)
+    for (; soft_thread < end_soft_thread; ++soft_thread)
 #define MOVES_GROW_BY 16
 
 typedef struct
@@ -272,8 +272,8 @@ struct fc_solve_hard_thread_struct
 #ifndef FCS_SINGLE_HARD_THREAD
     /*
      * The hard thread count of how many states he checked himself. The
-     * instance num_checked_states can be confusing because other threads modify
-     * it too.
+     * instance num_checked_states can be confusing because other threads
+     * modify it too.
      *
      * Thus, the soft thread switching should be done based on this variable
      * */
@@ -304,8 +304,8 @@ struct fc_solve_hard_thread_struct
 #endif
 
     /*
-     * This is a buffer used to temporarily store the stacks of the duplicated
-     * state.
+     * This is a buffer used to temporarily store the stacks of the
+     * duplicated state.
      * */
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
 
@@ -322,8 +322,8 @@ struct fc_solve_hard_thread_struct
 
     /*
      * A counter that determines how many of the soft threads that belong
-     * to this hard thread have already finished. If it becomes num_soft_threads
-     * this thread is skipped.
+     * to this hard thread have already finished. If it becomes
+     * num_soft_threads this thread is skipped.
      * */
     int num_soft_threads_finished;
 
@@ -344,10 +344,10 @@ typedef struct
 {
     fcs_collectible_state_t *state;
     fcs_derived_states_list_t derived_states_list;
-    int_fast32_t move_func_list_idx;
-    int current_state_index;
-    int move_func_idx;
-    int derived_states_random_indexes_max_size;
+    size_t move_func_list_idx;
+    size_t current_state_index;
+    size_t move_func_idx;
+    size_t derived_states_random_indexes_max_size;
     fcs_rating_with_index_t *derived_states_random_indexes;
     fcs__positions_by_rank_t positions_by_rank;
     fcs_game_limit_t num_vacant_stacks;
@@ -362,7 +362,7 @@ typedef struct
 
 typedef struct
 {
-    int num_units;
+    size_t num_units;
     fcs_moves_by_depth_unit_t *by_depth_units;
 } fcs_moves_by_depth_array;
 
@@ -407,9 +407,9 @@ struct fc_solve_soft_thread_struct
             /*
              * Soft-DFS uses a stack of fcs_soft_dfs_stack_item_t s.
              *
-             * derived_states_list - a list of states to be checked next. Not
-             * all of them will be checked because it is possible that future
-             * states already visited them.
+             * derived_states_list - a list of states to be checked next.
+             * Not all of them will be checked because it is possible that
+             * future states already visited them.
              *
              * current_state_index - the index of the last checked state
              * in depth i.
@@ -431,7 +431,8 @@ struct fc_solve_soft_thread_struct
             ssize_t depth;
 
             /*
-             * A pseudo-random number generator for use in the random-DFS scan
+             * A pseudo-random number generator for use in the random-DFS
+             * scan
              * */
             fcs_rand_t rand_gen;
 
@@ -454,7 +455,8 @@ struct fc_solve_soft_thread_struct
                 struct
                 {
                     /*
-                     * A linked list that serves as the queue for the BFS scan.
+                     * A linked list that serves as the queue for the BFS
+                     * scan.
                      * */
                     fcs_states_linked_list_item_t *bfs_queue;
                     /*
@@ -547,8 +549,9 @@ struct fc_solve_instance_struct
 
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
     /*
-     * Limit for the maximal number of checked states. max_num_checked_states
-     * is useful because it can limit the amount of consumed memory (and time).
+     * Limit for the maximal number of checked states.
+     * max_num_checked_states is useful because it can limit the amount of
+     * consumed memory (and time).
      *
      * This is the effective number that enables the process to work without
      * checking if it's zero.
@@ -684,8 +687,8 @@ struct fc_solve_instance_struct
 
     /*
      * A counter that determines how many of the hard threads that belong
-     * to this hard thread have already finished. If it becomes num_hard_threads
-     * the instance terminates.
+     * to this hard thread have already finished. If it becomes
+     * num_hard_threads the instance terminates.
      * */
     int num_hard_threads_finished;
 
@@ -710,7 +713,8 @@ struct fc_solve_instance_struct
      * The debug_iter_output variables provide a programmer programmable way
      * to debug the algorithm while it is running. This works well for DFS
      * and Soft-DFS scans but at present support for BeFS and BFS is not
-     * too good, as its hard to tell which state came from which parent state.
+     * too good, as its hard to tell which state came from which parent
+     * state.
      *
      * debug_iter_output_func is a pointer to the function that performs the
      * debugging. If NULL, this feature is not used.
@@ -813,9 +817,6 @@ struct fc_solve_instance_struct
 extern fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     fc_solve_soft_thread_t *const soft_thread);
 
-extern void fc_solve_increase_dfs_max_depth(
-    fc_solve_soft_thread_t *const soft_thread);
-
 static inline void *memdup(const void *const src, const size_t my_size)
 {
     void *const dest = malloc(my_size);
@@ -838,7 +839,7 @@ static inline int update_col_cards_under_sequences(
 )
 {
     fcs_card_t this_card = fcs_col_get_card(col, d);
-    fcs_card_t prev_card = fcs_col_get_card(col, d - 1);
+    fcs_card_t prev_card;
     for (; (d > 0) && ({
              prev_card = fcs_col_get_card(col, d - 1);
              fcs_is_parent_card(this_card, prev_card);
@@ -880,7 +881,7 @@ static inline fcs_moves_order moves_order_dup(fcs_moves_order *const orig)
             sizeof(orig->groups[0]) *
                 ((num & (~(MOVES_GROW_BY - 1))) + MOVES_GROW_BY))};
 
-    for (int i = 0; i < num; i++)
+    for (size_t i = 0; i < num; ++i)
     {
         ret.groups[i].move_funcs = memdup(ret.groups[i].move_funcs,
             sizeof(ret.groups[i].move_funcs[0]) *
