@@ -17,7 +17,7 @@
 
 #include <tap.h>
 #include "config.h"
-#include "../bit_rw.h"
+#include "bit_rw.h"
 
 static int main_tests(void)
 {
